package com.qspda.activity;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.RadioGroup.OnCheckedChangeListener;
import android.widget.Toast;


/**
 * 获取扫描信息
 *
 * @author wusiliang
 * @time 2020年9月22日11:48:32
 *
 */
public class MainActivity extends Activity {

    Intent mIntent_text = new Intent("COM.QS5501.PRINTTEXT");
    Intent mIntent_bitmap = new Intent("COM.QS5501.PRINTBITMAP");
    Intent mIntent_barcode = new Intent("COM.QS5501.PRINTBARCODE");
    Intent mIntent_qrcode = new Intent("COM.QS5501.PRINTQRCODE");
    Intent mIntent_sendCMD = new Intent("COM.QS5501.PRINTSENDCMD");

    Intent mIntent = new Intent("ismart.intent.scandown");

    private Bitmap btMap = null;

    private ScanBroadcastReceiver scanBroadcastReceiver;

    private GetMessageBroadcastReceiver getMessageBroadcastReceiver;

    private EditText tv;

    private RadioGroup rg;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        // TODO Auto-generated method stub
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        tv = (EditText) findViewById (R.id.tv);
        rg = (RadioGroup) findViewById (R.id.rg);

        /**
         * 打印文字
         */
        findViewById(R.id.btn_printText).setOnClickListener(
                new OnClickListener () {

                    @Override
                    public void onClick(View v) {
                        // TODO Auto-generated method stub

                        String barStr = tv . getText ().toString();

                        // 添加内容
                        mIntent_text.putExtra("text", barStr);
                        // 添加对齐方式，0为左对齐，1为居中，2为居右
                        mIntent_text.putExtra("align", 0);
                        // 添加文字大小设置， 1为正常字体，2为双倍字体
                        mIntent_text.putExtra("size", 1);
                        // 发送打印广播
                        sendBroadcast(mIntent_text);

                    }
                });

        /**
         * 打印条码
         */
        findViewById(R.id.btn_printBarcode).setOnClickListener(
                new OnClickListener () {
                    @Override
                    public void onClick(View arg0) {
                        // TODO Auto-generated method stub

                        String barStr = tv . getText ().toString();

                        if (barStr == null || barStr.length() <= 0)
                            return;

                        // 判断当前字符能否生成条码
                        if (barStr.getBytes().length > barStr.length()) {
                            Toast.makeText(MainActivity.this, "当前数据不能生成一维码",
                                    Toast.LENGTH_SHORT).show();
                            return;
                        }

                        // 添加一维码内容
                        mIntent_barcode.putExtra("text", barStr.trim());
                        // 添加对齐方式，0为左对齐，1为居中，2为居右
                        mIntent_barcode.putExtra("align", 1);
                        //条码宽度，58纸张最大宽度为384
                        mIntent_barcode.putExtra("width", 384);
                        //条码高度
                        mIntent_barcode.putExtra("height", 100);
                        //条码内容是否显示,true显示，false不显示
                        mIntent_barcode.putExtra("showStr", true);
                        //条码内容大小,单位是sp,默认是21
                        mIntent_barcode.putExtra("size", 21);
                        // 发送打印广播
                        sendBroadcast(mIntent_barcode);

                    }
                });

        /**
         * 打印二维码
         */
        findViewById(R.id.btn_printQRcode).setOnClickListener(
                new OnClickListener () {
                    @Override
                    public void onClick(View arg0) {
                        // TODO Auto-generated method stub

                        String qrStr = tv . getText ().toString();

                        if (qrStr == null || qrStr.length() <= 0) {
                            Toast.makeText(MainActivity.this, "当前数据不能为空",
                                    Toast.LENGTH_SHORT).show();
                            return;
                        }

                        // 添加一维码内容
                        mIntent_qrcode.putExtra("text", qrStr.trim());
                        // 添加对齐方式，0为左对齐，1为居中，2为居右
                        mIntent_qrcode.putExtra("align", 1);
                        //二维码宽度，58纸张最大宽度为384
                        mIntent_qrcode.putExtra("width", 200);
                        //二维码高度
                        mIntent_qrcode.putExtra("height", 200);
                        //二维码内容是否显示,true显示，false不显示
                        mIntent_qrcode.putExtra("showStr", true);
                        //二维码内容大小,单位是sp,默认是21
                        mIntent_qrcode.putExtra("size", 25);

                        // 发送打印广播
                        sendBroadcast(mIntent_qrcode);

                    }
                });

        /**
         * 打印图片
         */
        findViewById(R.id.btn_printImage).setOnClickListener(
                new OnClickListener () {
                    @Override
                    public void onClick(View v) {
                        // TODO Auto-generated method stub
                        // 获取图片
                        btMap = BitmapFactory.decodeResource(getResources(),
                                R.drawable.demo);

                        mIntent_bitmap.putExtra("bitmap", btMap);

                        // 添加对齐方式，0为居左，1为居中，2为居右
                        mIntent_bitmap.putExtra("align", 1);

                        //图片宽度，58纸张最大宽度为384，80为570
                        mIntent_bitmap.putExtra("width", 300);
                        //图片高度，一般不超过10cm
                        mIntent_bitmap.putExtra("height", 300);

                        sendBroadcast(mIntent_bitmap);

                    }
                });

        /**
         * 扫描
         */
        findViewById(R.id.btn_scan1).setOnClickListener(new OnClickListener () {

            @Override
            public void onClick(View v) {
                // TODO Auto-generated method stub
                // 触发扫描
                sendBroadcast(mIntent);

            }
        });

        /**
         * 纸张类型选择
         */
        rg.setOnCheckedChangeListener(new OnCheckedChangeListener () {

            @Override
            public void onCheckedChanged(RadioGroup arg0, int arg1) {
                // TODO Auto-generated method stub
                //普通热敏纸
                if (arg1 == R.id.rbtn1) {

                    // 关闭黑标指令
                    byte[] bt1 = new byte[] {
                            0x1F, 0x1B, 0x1F, (byte) 0x80, 0x04,
                            0x05, 0x06, 0x66
                    };

                    mIntent_sendCMD.putExtra("cmd", bt1);

                    sendBroadcast(mIntent_sendCMD);

                }
                //间隙标签纸
                else {

                    // 开启黑标指令
                    byte[] bt2 = new byte[] {
                            0x1F, 0x1B, 0x1F, (byte) 0x80, 0x04,
                            0x05, 0x06, 0x44
                    };

                    mIntent_sendCMD.putExtra("cmd", bt2);

                    sendBroadcast(mIntent_sendCMD);

                }
            }
        });


        scanBroadcastReceiver = new ScanBroadcastReceiver ();
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("com.qs.scancode");
        this.registerReceiver(scanBroadcastReceiver, intentFilter);

        getMessageBroadcastReceiver = new GetMessageBroadcastReceiver ();
        IntentFilter intentFilter_getMessage = new IntentFilter();
        intentFilter_getMessage.addAction("com.qs.getmassage");
        this.registerReceiver(getMessageBroadcastReceiver, intentFilter_getMessage);

    }

    /**
     * 获取扫描信息
     *
     * @author wu
     *
     */
    class ScanBroadcastReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
            // TODO Auto-generated method stub
            String text1 = intent . getExtras ().getString("data");
            Toast.makeText(context, "扫描信息：" + text1, Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * 打印信息接收
     *
     * @author wu
     *
     */
    class GetMessageBroadcastReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
            // TODO Auto-generated method stub
            int message = intent . getIntExtra ("message", 0);
            switch(message) {
                case 0:
                    //print success
                    Toast.makeText(context, "打印成功 complete", Toast.LENGTH_SHORT).show();
                    break;
                case 1:
                    //no paper
                    Toast.makeText(context, "缺纸 nopaper", Toast.LENGTH_SHORT).show();
                    break;
                default:
                    break;
            }
        }
    }

    @Override
    protected void onDestroy() {
        // TODO Auto-generated method stub
        unregisterReceiver(scanBroadcastReceiver);
        unregisterReceiver(getMessageBroadcastReceiver);
        super.onDestroy();
    }

}
